==> flink-core-1.0.0-sources.jar: org/apache/flink/api/common/accumulators/IntCounter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package org.apache.flink.api.common.accumulators;


import org.apache.flink.annotation.PublicEvolving;

/**
 * An accumulator that sums up {@code Integer} values.
 */
@PublicEvolving
public class IntCounter implements SimpleAccumulator<Integer> {

	private static final long serialVersionUID = 1L;

	private int localValue = 0;

	/**
	 * Consider using {@link #add(int)} instead for primitive int values
	 */
	@Override
	public void add(Integer value) {
		localValue += value;
	}

	public void add(int value){
		localValue += value;
	}

	@Override
	public Integer getLocalValue() {
		return localValue;
	}

	@Override
	public void merge(Accumulator<Integer, Integer> other) {
		this.localValue += other.getLocalValue();
	}

	@Override
	public void resetLocal() {
		this.localValue = 0;
	}

	@Override
	public Accumulator<Integer, Integer> clone() {
		IntCounter result = new IntCounter();
		result.localValue = localValue;
		return result;
	}

	@Override
	public String toString() {
		return "IntCounter " + this.localValue;
	}
}

==> flink-core-1.7.2-sources.jar: org/apache/flink/api/common/accumulators/IntCounter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.api.common.accumulators;

import org.apache.flink.annotation.PublicEvolving;

/**
 * An accumulator that sums up {@code Integer} values.
 */
@PublicEvolving
public class IntCounter implements SimpleAccumulator<Integer> {

	private static final long serialVersionUID = 1L;

	private int localValue = 0;

	public IntCounter() {}

	public IntCounter(int value) {
		this.localValue = value;
	}

	// ------------------------------------------------------------------------
	//  Accumulator
	// ------------------------------------------------------------------------

	/**
	 * Consider using {@link #add(int)} instead for primitive int values
	 */
	@Override
	public void add(Integer value) {
		localValue += value;
	}

	@Override
	public Integer getLocalValue() {
		return localValue;
	}

	@Override
	public void merge(Accumulator<Integer, Integer> other) {
		this.localValue += other.getLocalValue();
	}

	@Override
	public void resetLocal() {
		this.localValue = 0;
	}

	@Override
	public IntCounter clone() {
		IntCounter result = new IntCounter();
		result.localValue = localValue;
		return result;
	}

	// ------------------------------------------------------------------------
	//  Primitive Specializations
	// ------------------------------------------------------------------------

	public void add(int value){
		localValue += value;
	}

	public int getLocalValuePrimitive() {
		return this.localValue;
	}

	// ------------------------------------------------------------------------
	//  Utilities
	// ------------------------------------------------------------------------

	@Override
	public String toString() {
		return "IntCounter " + this.localValue;
	}
}
